GoOp class

Inheritance

Constructors

GoOp(Enum screen, Object? id, {bool edgeRequired = false})
const

Properties

edgeRequired bool
final
hashCode int
The hash code for this object.
no setterinherited
id Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen Enum
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited